==> haskell-cassava-0.4.5.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.0
id: cassava-0.4.5.0-LCutYytXWri1WnJj44KTfC
key: cassava-0.4.5.0-LCutYytXWri1WnJj44KTfC
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: a20578e131c7e223d548bb8a166debab
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/cassava-0.4.5.0
hs-libraries: HScassava-0.4.5.0-LCutYytXWri1WnJj44KTfC
depends:
    array-0.5.1.1 attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.4.5.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.1
id: cassava-0.4.5.1-HZhCjC2QfBY8Xid8583rBT
key: cassava-0.4.5.1-HZhCjC2QfBY8Xid8583rBT
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: 7e8879e624a21c1c57387b05912fae85
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/cassava-0.4.5.1
hs-libraries: HScassava-0.4.5.1-HZhCjC2QfBY8Xid8583rBT
depends:
    array-0.5.1.1 attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
